@@ -1,6 +1,8 @@
 # tm transformations
 
-setGeneric("tmTagPOS", function(object, language = "en", model = NULL, tagdict = NULL, ...) standardGeneric("tmTagPOS"))
+setGeneric("tmTagPOS",
+           function(object, language = "en", model = NULL, tagdict = NULL, ...)
+           standardGeneric("tmTagPOS"))
 setMethod("tmTagPOS",
           signature(object = "PlainTextDocument"),
           function(object, language = "en", model = NULL, tagdict = NULL, ...) {
@@ -8,7 +10,9 @@ setMethod("tmTagPOS",
               return(object)
           })
 
-setGeneric("tmSentDetect", function(object, language = "en", model = NULL, ...) standardGeneric("tmSentDetect"))
+setGeneric("tmSentDetect",
+           function(object, language = "en", model = NULL, ...)
+           standardGeneric("tmSentDetect"))
 setMethod("tmSentDetect",
           signature(object = "PlainTextDocument"),
           function(object, language = "en", model = NULL, ...) {
@@ -16,7 +20,9 @@ setMethod("tmSentDetect",
               return(object)
           })
 
-setGeneric("tmTokenize", function(object, language = "en", model = NULL, ...) standardGeneric("tmTokenize"))
+setGeneric("tmTokenize",
+           function(object, language = "en", model = NULL, ...)
+           standardGeneric("tmTokenize"))
 setMethod("tmTokenize",
           signature(object = "PlainTextDocument"),
           function(object, language = "en", model = NULL, ...) {
